@@ -8,7 +8,7 @@ use Data::Dumper;
 
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
-our $VERSION = '1.16';
+our $VERSION = '1.17';
 our $AUTOLOAD;
 
 sub new {
@@ -64,7 +64,7 @@ sub set_aipost_prompt_url {
 }
 
 # Set agent_meta_data 
-sub set_aimeta_data {
+sub set_agent_meta_data {
     my $self = shift;
 
     $self->{_agent_meta_data} = shift;
